@@ -1,3 +1,5 @@
+import os, random, sys, cv2, time, csv
+os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 from scipy.io import loadmat, whosmat
 from scipy.io.wavfile import write
 from scipy import signal
@@ -11,14 +13,12 @@ from tkinter.ttk import Progressbar, Separator
 from tkinter import filedialog as fd 
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
+from matplotlib.cm import jet
 from pygame.mixer import Sound, init, quit, get_init, set_num_channels
-import os, random, sys, cv2, time, csv
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 
 def AE_init():
-	AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
 	if not os.path.isdir(AE_path):
-		print('Cloning the audio engine to the anthem package directory...')
+		print('Cloning the audio engine to the pyanthem package directory...')
 		Repo.clone_from('https://github.com/nicthib/AE.git',AE_path)
 		print('Audio engine downloaded to {}'.format(AE_path))
 	else:
@@ -36,7 +36,11 @@ class GUI(Tk):
 	def __init__(self):
 		Tk.__init__(self)
 		self.rootpath = os.path.split(os.path.realpath(__file__))[0]
-		if not os.path.isdir(os.path.join(self.rootpath,'AE')):
+		if __name__ == "__main__":
+			AE_path = r'C:\Users\dnt21\AppData\Local\Programs\Python\Python37-32\Lib\site-packages\pyanthem\AE'
+		else:
+			AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
+		if not os.path.isdir(AE_path):
 			print('ERROR: Audio engine not downloaded. Please do so using the command AE_init()')
 			self.runGUI = False
 		else:
@@ -93,7 +97,7 @@ class GUI(Tk):
 		self.init_plots()
 		if self.frameslider.get() > len(self.H_pp.T):
 			self.frameslider.set(1)
-		self.cmap = matplotlib.cm.jet(np.linspace(0,1,len(self.H_fp)))
+		self.cmap = jet(np.linspace(0,1,len(self.H_fp)))
 		Hstd = self.H_pp.std()*3
 		if self.offsetH.get():
 			tmpH = self.H_pp.T + repmat([w*Hstd for w in self.Wshow],len(self.H_pp.T),1)
